@@ -8,7 +8,6 @@ from seleniumwire.thirdparty.mitmproxy.net.http.headers import Headers
 
 
 class InterceptRequestHandlerTest(TestCase):
-
     def test_request_modifier_called(self):
         mock_flow = Mock()
         mock_flow.request.url = 'http://somewhere.com/some/path'
@@ -79,12 +78,19 @@ class InterceptRequestHandlerTest(TestCase):
         mock_flow.response.headers = Headers([(b'Content-Length', b'6')])
         mock_flow.response.raw_content = b'foobar'
         mock_cert = Mock()
-        mock_cert.subject = 'test_subject'
-        mock_cert.serial = 'test_serial'
-        mock_cert.keyinfo = 'test_key'
-        mock_cert.x509.get_signature_algorithm.return_value = 'test_algo'
+        mock_cert.subject = [(b'C', b'US'), (b'O', b'Mozilla Corporation')]
+        mock_cert.serial = 123456789
+        mock_cert.keyinfo = ('RSA', 2048)
+        mock_cert.x509.get_signature_algorithm.return_value = b'test_algo'
         mock_cert.has_expired = False
-        mock_cert.issuer = 'test_issuer'
+        mock_cert.issuer = [(b'CN', b'DigiCert SHA2 Secure Server CA')]
+        mock_cert.organization = b'Mozilla Corporation'
+        mock_cert.cn = b'*.cdn.mozilla.net'
+        mock_cert.altnames = [b'*.cdn.mozilla.net', b'cdn.mozilla.net']
+        notbefore = datetime.now()
+        notafter = datetime.now()
+        mock_cert.notbefore = notbefore
+        mock_cert.notafter = notafter
         mock_flow.server_conn.cert = mock_cert
         saved_response = None
 
@@ -101,12 +107,37 @@ class InterceptRequestHandlerTest(TestCase):
         self.assertEqual('OK', saved_response.reason)
         self.assertEqual({'Content-Length': '6'}, dict(saved_response.headers))
         self.assertEqual(b'foobar', saved_response.body)
-        self.assertEqual('test_subject', saved_response.cert['subject'])
-        self.assertEqual('test_serial', saved_response.cert['serial'])
-        self.assertEqual('test_key', saved_response.cert['key'])
-        self.assertEqual('test_algo', saved_response.cert['signature_algorithm'])
+        self.assertEqual([(b'C', b'US'), (b'O', b'Mozilla Corporation')], saved_response.cert['subject'])
+        self.assertEqual(123456789, saved_response.cert['serial'])
+        self.assertEqual(('RSA', 2048), saved_response.cert['key'])
+        self.assertEqual(b'test_algo', saved_response.cert['signature_algorithm'])
         self.assertFalse(saved_response.cert['expired'])
-        self.assertEqual('test_issuer', saved_response.cert['issuer'])
+        self.assertEqual([(b'CN', b'DigiCert SHA2 Secure Server CA')], saved_response.cert['issuer'])
+        self.assertEqual(notbefore, saved_response.cert['notbefore'])
+        self.assertEqual(notafter, saved_response.cert['notafter'])
+        self.assertEqual(b'Mozilla Corporation', saved_response.cert['organization'])
+        self.assertEqual(b'*.cdn.mozilla.net', saved_response.cert['cn'])
+        self.assertEqual([b'*.cdn.mozilla.net', b'cdn.mozilla.net'], saved_response.cert['altnames'])
+
+    def test_multiple_response_headers(self):
+        mock_flow = Mock()
+        mock_flow.request.id = '12345'
+        mock_flow.request.url = 'http://somewhere.com/some/path'
+        mock_flow.response.status_code = 200
+        mock_flow.response.reason = 'OK'
+        mock_flow.response.headers = Headers([(b'Set-Cookie', b'12345'), (b'Set-Cookie', b'67890')])
+        mock_flow.response.raw_content = b'foobar'
+        saved_response = None
+
+        def save_response(_, response):
+            nonlocal saved_response
+            saved_response = response
+
+        self.proxy.storage.save_response.side_effect = save_response
+
+        self.handler.response(mock_flow)
+
+        self.assertEqual([('Set-Cookie', '12345'), ('Set-Cookie', '67890')], saved_response.headers.items())
 
     def test_ignore_response_when_no_request(self):
         mock_flow = Mock()
@@ -195,11 +226,7 @@ class InterceptRequestHandlerTest(TestCase):
         mock_flow.request.raw_content = b''
 
         def intercept(req):
-            req.create_response(
-                status_code=200,
-                headers={'a': 'b'},
-                body=b'foobarbaz'
-            )
+            req.create_response(status_code=200, headers={'a': 'b'}, body=b'foobarbaz')
 
         self.proxy.request_interceptor = intercept
 
@@ -241,19 +268,14 @@ class InterceptRequestHandlerTest(TestCase):
         mock_handshake_flow.request.id = '12345'
         mock_flow = Mock()
         mock_flow.handshake_flow = mock_handshake_flow
-        mock_flow.messages = [Mock(
-            from_client=True,
-            content='test message',
-            timestamp=1614069300.0
-        )]
+        mock_flow.messages = [Mock(from_client=True, content='test message', timestamp=1614069300.0)]
 
         self.handler.websocket_message(mock_flow)
 
-        self.proxy.storage.save_ws_message.assert_called_once_with('12345', WebSocketMessage(
-            from_client=True,
-            content='test message',
-            date=datetime.fromtimestamp(1614069300.0)
-        ))
+        self.proxy.storage.save_ws_message.assert_called_once_with(
+            '12345',
+            WebSocketMessage(from_client=True, content='test message', date=datetime.fromtimestamp(1614069300.0)),
+        )
 
     def test_save_websocket_message_no_request(self):
         """If the handshake request was not saved (has no id) then
@@ -275,15 +297,13 @@ class InterceptRequestHandlerTest(TestCase):
         self.proxy.options['enable_har'] = True
         mock_flow = Mock()
         mock_flow.request.id = '12345'
-        mock_flow.response.headers = {}
+        mock_flow.response.headers = Headers()
         mock_flow.response.raw_content = b''
         mock_har.create_har_entry.return_value = {'name': 'test_har_entry'}
 
         self.handler.response(mock_flow)
 
-        self.proxy.storage.save_har_entry.assert_called_once_with(
-            '12345', {'name': 'test_har_entry'}
-        )
+        self.proxy.storage.save_har_entry.assert_called_once_with('12345', {'name': 'test_har_entry'})
         mock_har.create_har_entry.assert_called_once_with(mock_flow)
 
     @patch('seleniumwire.handler.har')
@@ -291,7 +311,7 @@ class InterceptRequestHandlerTest(TestCase):
         self.proxy.options['enable_har'] = False
         mock_flow = Mock()
         mock_flow.request.id = '12345'
-        mock_flow.response.headers = {}
+        mock_flow.response.headers = Headers()
         mock_flow.response.raw_content = b''
         mock_har.create_har_entry.return_value = {'name': 'test_har_entry'}
 
